@@ -1,5 +1,5 @@
 package Log::Contextual;
-$Log::Contextual::VERSION = '0.006004';
+$Log::Contextual::VERSION = '0.007000';
 # ABSTRACT: Simple logging interface with a contextual log
 
 use strict;
@@ -19,6 +19,7 @@ sub stash_name {
    ref $coderef or return;
    my $cv = B::svref_2object($coderef);
    $cv->isa('B::CV') or return;
+
    # bail out if GV is undefined
    $cv->GV->isa('B::SPECIAL') and return;
 
@@ -52,7 +53,7 @@ eval {
 # export anything but the levels selected
 sub ____ { }
 
-exports('____', @dlog, @log, qw( set_logger with_logger ));
+exports('____', @dlog, @log, qw( set_logger with_logger has_logger ));
 
 export_tag dlog => ('____');
 export_tag log  => ('____');
@@ -118,91 +119,78 @@ sub before_import {
       );
    }
 
+   if ($exports->{'&has_logger'}) {
+      die ref($router) . " does not support has_logger()"
+        unless $router->does('Log::Contextual::Role::Router::HasLogger');
+
+      _maybe_export($spec, $importer, 'has_logger',
+         sub { $router->has_logger(@_) },
+      );
+   }
+
    my @levels = @{$class->arg_levels($spec->config->{levels})};
    for my $level (@levels) {
+      my %base =
+        (exporter => $class, caller_level => 1, message_level => $level);
+      my %exports;
       if ($spec->config->{log} || $exports->{"&log_$level"}) {
-         _maybe_export(
-            $spec,
-            $importer,
-            "log_$level",
-            sub (&@) {
-               my ($code, @args) = @_;
-               $router->handle_log_request(
-                  exporter       => $class,
-                  caller_package => scalar(caller),
-                  caller_level   => 1,
-                  message_level  => $level,
-                  message_sub    => $code,
-                  message_args   => \@args,
-               );
-               return @args;
-            },
-         );
+         $exports{log_} = sub (&@) {
+            my ($code, @args) = @_;
+            $router->handle_log_request(
+               %base,
+               caller_package => scalar(caller),
+               message_sub    => $code,
+               message_args   => \@args,
+            );
+            return @args;
+         };
       }
       if ($spec->config->{log} || $exports->{"&logS_$level"}) {
-         _maybe_export(
-            $spec,
-            $importer,
-            "logS_$level",
-            sub (&@) {
-               my ($code, @args) = @_;
-               $router->handle_log_request(
-                  exporter       => $class,
-                  caller_package => scalar(caller),
-                  caller_level   => 1,
-                  message_level  => $level,
-                  message_sub    => $code,
-                  message_args   => \@args,
-               );
-               return $args[0];
-            },
-         );
+         $exports{logS_} = sub (&@) {
+            my ($code, @args) = @_;
+            $router->handle_log_request(
+               %base,
+               caller_package => scalar(caller),
+               message_sub    => $code,
+               message_args   => \@args,
+            );
+            return $args[0];
+         };
       }
       if ($spec->config->{dlog} || $exports->{"&Dlog_$level"}) {
-         _maybe_export(
-            $spec,
-            $importer,
-            "Dlog_$level",
-            sub (&@) {
-               my ($code, @args) = @_;
-               my $wrapped = sub {
-                  local $_ = (@_ ? Data::Dumper::Concise::Dumper @_ : '()');
-                  &$code;
-               };
-               $router->handle_log_request(
-                  exporter       => $class,
-                  caller_package => scalar(caller),
-                  caller_level   => 1,
-                  message_level  => $level,
-                  message_sub    => $wrapped,
-                  message_args   => \@args,
-               );
-               return @args;
-            },
-         );
+         $exports{Dlog_} = sub (&@) {
+            my ($code, @args) = @_;
+            my $wrapped = sub {
+               local $_ = (@_ ? Data::Dumper::Concise::Dumper @_ : '()');
+               &$code;
+            };
+            $router->handle_log_request(
+               %base,
+               caller_package => scalar(caller),
+               message_sub    => $wrapped,
+               message_args   => \@args,
+            );
+            return @args;
+         };
       }
       if ($spec->config->{dlog} || $exports->{"&DlogS_$level"}) {
-         _maybe_export(
-            $spec,
-            $importer,
-            "DlogS_$level",
-            sub (&$) {
-               my ($code, $ref) = @_;
-               my $wrapped = sub {
-                  local $_ = Data::Dumper::Concise::Dumper($_[0]);
-                  &$code;
-               };
-               $router->handle_log_request(
-                  exporter       => $class,
-                  caller_package => scalar(caller),
-                  caller_level   => 1,
-                  message_level  => $level,
-                  message_sub    => $wrapped,
-                  message_args   => [$ref],
-               );
-               return $ref;
-            });
+         $exports{DlogS_} = sub (&$) {
+            my ($code, $ref) = @_;
+            my $wrapped = sub {
+               local $_ = Data::Dumper::Concise::Dumper($_[0]);
+               &$code;
+            };
+            $router->handle_log_request(
+               %base,
+               caller_package => scalar(caller),
+               message_sub    => $wrapped,
+               message_args   => [$ref],
+            );
+            return $ref;
+         };
       }
+      _maybe_export($spec, $importer, $_ . $level, $exports{$_})
+        for keys %exports;
    }
 }
 
@@ -240,7 +228,7 @@ Log::Contextual - Simple logging interface with a contextual log
 
 =head1 VERSION
 
-version 0.006004
+version 0.007000
 
 =head1 SYNOPSIS
 
@@ -504,6 +492,15 @@ C<with_logger> sets the logger for the scope of the C<CodeRef> C<$to_execute>.
 As with L</set_logger>, C<with_logger> will wrap C<$returning_logger> with a
 C<CodeRef> if needed.
 
+=head2 has_logger
+
+ my $logger = WarnLogger->new;
+ set_logger $logger unless has_logger;
+
+Arguments: none
+
+C<has_logger> will return true if a logger has been set.
+
 =head2 log_$level
 
 Import Tag: C<:log>
@@ -735,7 +732,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2016 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
