@@ -1,5 +1,7 @@
 package Log::Contextual::Role::Router::WithLogger;
-$Log::Contextual::Role::Router::WithLogger::VERSION = '0.006003';
+$Log::Contextual::Role::Router::WithLogger::VERSION = '0.007000';
+# ABSTRACT: Abstract interface between loggers and logging code blocks
+
 use Moo::Role;
 
 requires 'with_logger';
@@ -14,11 +16,11 @@ __END__
 
 =head1 NAME
 
-Log::Contextual::Role::Router::WithLogger
+Log::Contextual::Role::Router::WithLogger - Abstract interface between loggers and logging code blocks
 
 =head1 VERSION
 
-version 0.006003
+version 0.007000
 
 =head1 AUTHOR
 
@@ -26,7 +28,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2016 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
